roclet_find: Create a roclet from a string

View source: R/roclet.R

roclet_findR Documentation

Create a roclet from a string

Description

This provides a flexible way of specifying a roclet in a string.

Usage

roclet_find(x)

Arguments

x

Arbitrary R code evaluated in roxygen2 package.

See Also

Other extending: load_options(), parse_package(), rd_section(), roc_proc_text(), roxy_block(), roxy_tag(), roxy_tag_rd(), tag_parsers, tags_list()

Examples

# rd, namespace, and vignette work for backward compatibility
roclet_find("rd")

# But generally you should specify the name of a function that
# returns a roclet
roclet_find("rd_roclet")

# If it lives in another package, you'll need to use ::
roclet_find("roxygen2::rd_roclet")

# If it takes parameters (which no roclet does currently), you'll need
# to call the function
roclet_find("roxygen2::rd_roclet()")

roxygen2 documentation built on May 1, 2026, 5:06 p.m.