| roxy_tag | R Documentation |
roxy_tag S3 constructorroxy_tag() is the constructor for tag objects.
roxy_tag_warning() is superseded by warn_roxy_tag(); use to generate a
warning that includes the location of the tag.
roxy_tag(tag, raw, val = NULL, file = NA_character_, line = NA_character_)
roxy_tag_parse(x)
roxy_tag_warning(x, ...)
warn_roxy_tag(tag, message, parent = NULL, envir = parent.frame())
tag |
Tag name. Arguments starting with |
raw |
Raw tag value, a string. |
val |
Parsed tag value, typically a character vector, but sometimes
a list. Usually filled in by |
file, line |
Location of the tag |
x |
A tag |
... |
Additional data to be stored in the condition object.
If you supply condition fields, you should usually provide a
|
message |
Warning message |
parent |
Supply
For more information about error calls, see Including contextual information with error chains. |
envir |
passed to |
Define a method for roxy_tag_parse to support new tags. See tag_parsers
for more details.
Other extending:
load_options(),
parse_package(),
rd_section(),
roc_proc_text(),
roclet_find(),
roxy_block(),
roxy_tag_rd(),
tag_parsers,
tags_list()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.