Skip to content

Learn the full details in vignette('rd-other').

Key tags:

  • @format ${1:description}: Describe the type/shape of a dataset. If the dataset is a data frame, include a description of each column. If not supplied, will be automatically generated by object_format().

  • @source ${1:description}: Describe where the dataset came from. Provide a link to the original source (if possible) and briefly describe any manipulation that you performed when importing the data.

Usage

#' @format ${1:description}
#' @source ${1:description}

See also

Other documentation tags: tags-index-crossref, tags-rd, tags-rd-oop, tags-reuse