View source: R/roxygenize-needs.R
| needs_roxygenize | R Documentation |
A lightweight check that compares modification times of .Rd files in
man/ with the source files listed in their backrefs. This is much faster
than running roxygenize() but can suffer from both false negatives (e.g.
if an inherited documentation topic has changed) and false positives (e.g.
if a source file was modified but the change doesn't affect the
documentation).
needs_roxygenize(package.dir = ".", quiet = FALSE)
package.dir |
Location of package top level directory. Default is working directory. |
quiet |
If |
A logical value, invisibly. TRUE if any man pages appear
to be out of date; FALSE otherwise.
## Not run:
needs_roxygenize()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.