A lightweight check that compares modification times of .Rd files in
man/ with the source files listed in their backrefs. This is much faster
than running roxygenize() but can suffer from both false negatives (e.g.
if an inherited documentation topic has changed) and false positives (e.g.
if a source file was modified but the change doesn't affect the
documentation).