Learn R Programming

roxygen2 (version 8.1.0)

needs_roxygenize: Check if documentation needs to be updated

Description

A lightweight check that compares modification times of .Rd files in man/ with the source files listed in their backrefs. This is much faster than running roxygenize() but can suffer from both false negatives (e.g. if an inherited documentation topic has changed) and false positives (e.g. if a source file was modified but the change doesn't affect the documentation).

Usage

needs_roxygenize(package.dir = ".", quiet = FALSE)

Value

A logical value, invisibly. TRUE if any man pages appear to be out of date; FALSE otherwise.

Arguments

package.dir

Location of package top level directory. Default is working directory.

quiet

If TRUE, suppresses the message listing out-of-date man pages.

Examples

Run this code
if (FALSE) {
needs_roxygenize()
}

Run the code above in your browser using DataLab