These functions parse the raw tag value, convert a string into a richer R
object and storing it in val, or provide an informative warning and
returning NULL.
Usage
tag_value(x, multiline = FALSE)
tag_inherit(x)
tag_name(x)
tag_two_part(x, first, second, required = TRUE, markdown = TRUE)
tag_name_description(x)
tag_words(x, min = 0, max = Inf, multiline = FALSE)
tag_words_line(x)
tag_toggle(x)
tag_code(x)
tag_examples(x)
tag_markdown(x)
tag_markdown_with_sections(x)Arguments
- x
A roxy_tag object to parse
- multiline
If
FALSE(the default), tags that span multiple lines will generate a warning. Set toTRUEfor tags where multiline content is expected (e.g.,@usage,@rawRd).- first, second
Name of first and second parts of two part tags
- required
Is the second part required (TRUE) or can it be blank (FALSE)?
- markdown
Should the second part be parsed as markdown?
- min, max
Minimum and maximum number of words
Value
A roxy_tag object with the val field set to the parsed value.
New tag
To create a new @mytag define roxy_tag_parse.roxy_tag_mytag(). It should
either call one of the functions here, or directly set x$val.
See also
Other extending:
load_options(),
parse_package(),
rd_section(),
roc_proc_text(),
roclet_find(),
roxy_block(),
roxy_tag(),
roxy_tag_rd(),
tags_list()