Learn full the details in in vignette('index-crossref').
Key tags:
@aliases {alias}: Add additional aliases to the topic. Use NULL to suppress the default alias automatically generated by roxygen2.
@concept {concept}: Add additional keywords or phrases to be included in the help.search() index. Each @concept should be a single term or phrase.
@family {family name}: Generate @seealso entries to all other functions in family name.
@keywords {keyword}: Add a standardised keyword, indexed by help.search(). These are generally not useful apart from @keyword internal which flags the topic as internal and removes from topic indexes.
@references {reference}: Pointers to the related literature. Usually formatted like a bibliography.
@seealso {[func1()], <url1>}: Link to other related functions or urls. Usually a sentence or two, or a bulleted list.
Other less frequently used tags:
@backref {path}: Manually override the backreference that points from the .Rd file back to the source .R file. Only needed when generating code.
#' @aliases {alias}
#' @backref {path}
#' @concept {concept}
#' @family {family name}
#' @keywords {keyword}
#' @references {reference}
#' @seealso {[func1()], } Other documentation tags:
tags-rd-other,
tags-rd,
tags-reuse