Learn R Programming

roxygen2 (version 8.1.0)

tags-rd-datasets: Tags for documenting datasets

Description

Learn the full details in vignette('rd-datasets').

Key tags:

  • @format ${1:description}: Describe the type/shape of a dataset. If the dataset is a data frame, include a description of each column. If not supplied, will be automatically generated by object_format().

  • @source ${1:description}: Describe where the dataset came from. Provide a link to the original source (if possible) and briefly describe any manipulation that you performed when importing the data.

Usage

#' @format ${1:description}
#' @source ${1:description}

Arguments

See Also

Other documentation tags: tags-index-crossref, tags-rd-R6, tags-rd-S3, tags-rd-S4, tags-rd-S7, tags-rd-functions, tags-reuse