Learn the full details in vignette('rd-other').
Key tags:
@field ${1:name} ${2:description}: Describe a R6 or refClass field.@method ${1:generic} ${2:class}: Force a function to be recognised as an S3 method. This affects the default usage and theNAMESPACEdirective produced by@export. Only needed if automatic detection fails.@prop ${1:name} ${2:description}: Describe an S7 class property that is not a constructor parameter.@slot ${1:name} ${2:description}: Describe the slot of an S4 class.
Other less frequently used tags:
@R6method ${1:Class}$${2:method}: Document an R6 method that can't be discovered by introspection, such as methods added via$set().
Usage
#' @field ${1:name} ${2:description}
#' @method ${1:generic} ${2:class}
#' @prop ${1:name} ${2:description}
#' @R6method ${1:Class}$${2:method}
#' @slot ${1:name} ${2:description}See also
Other documentation tags:
tags-index-crossref,
tags-rd,
tags-rd-data,
tags-reuse